impl_poem_parameter

Macro impl_poem_parameter 

macro_rules! impl_poem_parameter {
    ($($ty:ty),*) => { ... };
}
This macro implements the traits necessary for using a type as a parameter in a poem-openapi endpoint handler, specifically as an argument like Path. A type must impl FromStr for this to work, hence why it is a seperate macro.