macro_rules! impl_poem_parameter {
($($ty:ty),*) => { ... };
}Expand description
This macro implements the traits necessary for using a type as a parameter
in a poem-openapi endpoint handler, specifically as an argument like Path
macro_rules! impl_poem_parameter {
($($ty:ty),*) => { ... };
}This macro implements the traits necessary for using a type as a parameter
in a poem-openapi endpoint handler, specifically as an argument like Path